==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/is.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: is.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $

$text['title']          = 'Kerfisupplsingar';

$text['vitals']         = 'Helstu Upplsingar';
$text['hostname']       = 'Vlarnafn';
$text['ip']             = 'IP Tala';
$text['kversion']       = 'tgfa kjarna';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uppitmi';
$text['users']          = 'Notendur';
$text['loadavg']        = 'Meal lag';

$text['hardware']       = 'Upplsingar um vlbna';
$text['numcpu']         = 'rgjrvi/rgjrvar';
$text['cpumodel']       = 'Tpa';
$text['mhz']            = 'Hrai';
$text['cache']          = 'Str fltiminnis';
$text['bogomips']       = 'Kerfis Bogomips';
$text['usb']            = 'USB Jaartki';
$text['pci']            = 'PCI Jaartki';
$text['ide']            = 'IDE Jaartki';
$text['scsi']           = 'SCSI Jaartki';

$text['netusage']       = 'Notkun Nets';
$text['device']         = 'Jaartki';
$text['received']       = 'Teki  mti';
$text['sent']           = 'Sent';
$text['errors']         = 'Villur/Drop';

$text['memusage']       = 'Minnisnotkun';
$text['phymem']         = 'Vinnsluminni';
$text['swap']           = 'Sndarminni';

$text['fs']             = 'Tengd Skrarkerfi';
$text['mount']          = 'Tengipunktur';
$text['partition']      = 'Disksnei';

$text['percent']        = 'Prsent af Heildarstr';
$text['type']           = 'Tpa';
$text['free']           = 'Laust';
$text['used']           = 'Nota';
$text['size']           = 'Str';
$text['totals']         = 'Samtals';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ekkert';

$text['capacity']       = 'Heildarstr'; 

$text['template']       = 'Template';
$text['language']       = 'Tunguml';
$text['submit']         = 'Senda';
$text['created']        = 'Bi til af';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'dagar';
$text['hours']          = 'klukkustundir';
$text['minutes']        = 'mntur';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/is.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: is.php,v 1.11 2004/08/30 15:51:26 webbie Exp $

$text['title']          = 'Kerfisupplsingar';

$text['vitals']         = 'Helstu upplsingar';
$text['hostname']       = 'Vlarnafn';
$text['ip']             = 'IP-tala';
$text['kversion']       = 'tgfa kjarna';
$text['dversion']       = 'Nafn dreifingar';
$text['uptime']         = 'Uppitmi';
$text['users']          = 'Notendur';
$text['loadavg']        = 'Meallag';

$text['hardware']       = 'Upplsingar um vlbna';
$text['numcpu']         = 'Fjldi rgjrva';
$text['cpumodel']       = 'Tegund';
$text['cpuspeed']       = 'Hrai';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Str fltiminnis';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'PCI jaartki';
$text['ide']            = 'IDE jaartki';
$text['scsi']           = 'SCSI jaartki';
$text['usb']            = 'USB jaartki';

$text['netusage']       = 'Netnotkun';
$text['device']         = 'Jaartki';
$text['received']       = 'Mtteki';
$text['sent']           = 'Sent';
$text['errors']         = 'Villur/Hent';

$text['memusage']       = 'Minnisnotkun';
$text['phymem']         = 'Vinnsluminni';
$text['swap']           = 'Sndarminni';

$text['fs']             = 'Tengd skrarkerfi';
$text['mount']          = 'Tengipunktur';
$text['partition']      = 'Disksnei';

$text['percent']        = 'Hlutfall af heildarstr';
$text['type']           = 'Tegund';
$text['free']           = 'Laust';
$text['used']           = 'Nota';
$text['size']           = 'Str';
$text['totals']         = 'Samtals';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ekkert';

$text['capacity']       = 'Heildarstr'; 

$text['template']       = 'Snimt';
$text['language']       = 'Tunguml';
$text['submit']         = 'Senda';
$text['created']        = 'Bi til af';
$text['locale']         = 'is_IS';
$text['gen_time']       = 'ann %d.%m.%Y kl. %R';

$text['days']           = 'dagar';
$text['hours']          = 'klukkustundir';
$text['minutes']        = 'mntur';
  
$text['temperature']    = 'Hitastig';
$text['voltage']        = 'Volt';
$text['fans']           = 'Viftur';
$text['s_value']        = 'Gildi';
$text['s_min']          = 'Lgst';
$text['s_max']          = 'Hst';
$text['s_div']          = 'Deilir';
$text['hysteresis']     = 'Avrun lkur';
$text['s_limit']        = 'Avrun byrjar';
$text['s_label']        = 'Nafn mlis';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
